@@ -421,7 +421,7 @@ def general_obj_search(request, Obj, ObjForm, search_fields=(), \
         result_fields=(), template=False, allow_prompt_ajax_search=False, \
         allow_overall_search=False, relational_obj_values={}, translations={}, \
         import_instruction_for_obj=False, import_instruction_for_report=False, \
-        *args, **kwargs):
+        ajax_url=False, *args, **kwargs):
     if not template:
         template = 'generalobj_search.html'
     ret_dic = {}
@@ -430,6 +430,8 @@ def general_obj_search(request, Obj, ObjForm, search_fields=(), \
             ret_dic['datetimefield_exists'], ret_dic['booleanfield_exists']) = \
             get_params_for_search(request, Obj, ObjForm, search_fields, \
             result_fields, relational_obj_values, translations)
+    if ajax_url:
+        ret_dic['ajax_url'] = ajax_url
     if 'passing_scripts' in kwargs:
         ret_dic['passing_scripts'] = kwargs['passing_scripts']
     ret_dic['url_new'] = reverse('%s_new' % ret_dic['class_name'].lower())
